### Name: rsf.default
### Title: Random Survival Forest Entry Point
### Aliases: rsf.default rsf randomSurvivalForest
### Keywords: survival tree

### ** Examples

# Example 1:  Veteran's Administration lung cancer trial from
# Kalbfleisch & Prentice.  Randomized trial of two treatment
# regimens for lung cancer.  Minimal argument call.  Print
# results, then plot error rate and importance values.

data(veteran, package = "randomSurvivalForest")
veteran.out <- rsf(Survrsf(time, status)~., data = veteran)
print(veteran.out)
plot(veteran.out)

# Example 2:  Richer argument call.
# Note that forest option is set to true to illustrate 
# how one might use 'rsf' for prediction (see 'rsf.predict'
# for more details).

data(veteran, package = "randomSurvivalForest")
veteran.f <- as.formula(Survrsf(time, status)~.)
ntree <- 200
mtry <- 2
nodesize <- 3
splitrule <- "logrankrandom"
varUsed <- "by.tree"
forest <- TRUE
proximity <- TRUE
seed <- -1
do.trace <- 25
veteran2.out <- rsf(veteran.f, veteran, ntree, mtry, nodesize, splitrule,
                    varUsed = varUsed, forest = forest, proximity = proximity,
                    seed = seed, do.trace = do.trace)
print(veteran2.out)
plot.proximity(veteran2.out)

# Take a peek at the forest ...
head(veteran2.out$forest$nativeArray)

# Average number of times a variable was split on.
apply(veteran2.out$varUsed,2,mean)

# Partial plot of top variable.
plot.variable(veteran2.out, partial = TRUE, n.pred=1)

## Not run: 
##D # Example 3:  Veteran data again. Look specifically at
##D # Karnofsky performance score.  Compare to Kaplan-Meier.
##D # Assumes "survival" library is loaded.
##D 
##D if (library("survival", logical.return = TRUE))
##D {
##D         data(veteran, package = "randomSurvivalForest")
##D         veteran3.out <- rsf(Survrsf(time, status)~karno,
##D                        veteran,
##D                        ntree = 1000)
##D         plot.ensemble(veteran3.out)
##D         par(mfrow = c(1,1))
##D         plot(survfit(Surv(time, status)~karno, data = veteran))
##D }
##D 
##D # Example 4:  Primary biliary cirrhosis (PBC) of the liver.
##D # Data found in Appendix D.1 of Fleming and Harrington, Counting
##D # Processes and Survival Analysis, Wiley, 1991 (only differences
##D # are that age is in days and sex and stage variables are not
##D # missing for observations 313-418).  
##D 
##D data(pbc, package = "randomSurvivalForest") 
##D pbc.out <- rsf(Survrsf(days,status)~., pbc, ntree = 1000)
##D print(pbc.out)
##D 
##D # Example 5:  Same as Example 4, but with imputation for missing values.
##D 
##D data(pbc, package = "randomSurvivalForest") 
##D pbc2.out <- rsf(Survrsf(days,status)~., pbc, ntree = 1000, na.action="na.impute")
##D # summary of analysis
##D print(pbc2.out)
##D # Combine original data + imputed data.
##D pbc.imputed.data <- cbind(status=pbc2.out$cens, days=pbc2.out$time, pbc2.out$predictors)
##D pbc.imputed.data[pbc2.out$imputedIndv,] <- pbc2.out$imputedData
##D tail(pbc)
##D tail(pbc.imputed.data)
##D # Iterate the missing data algorithm.
##D # Use random splitting to increase speed.
##D # Use trace to track algorithm in detail.
##D # Note that a side effect of iterating is that the original data
##D # are replaced by imputed values.
##D pbc3.out <- rsf(Survrsf(days,status)~., pbc, ntree = 1000,
##D          splitrule = "logrankrandom",  na.action="na.impute", nimpute=3, do.trace = 100)
##D pbc.iterate.imputed.data <- cbind(status=pbc3.out$cens,
##D          days=pbc3.out$time, pbc3.out$predictors)
##D 
##D # Example 6:  Compare Cox regression to RSF (PBC data).
##D # Compute OOB estimate of Harrell's concordance 
##D # index for Cox regression using B = 100 bootstrap draws.
##D # Assumes "Hmisc" and "survival" libraries are loaded. 
##D 
##D if (library("survival", logical.return = TRUE) 
##D     & library("Hmisc", logical.return = TRUE))
##D {
##D     data(pbc, package = "randomSurvivalForest")
##D     pbc3.out <- rsf(Survrsf(days,status)~., pbc, mtry = 2, ntree = 1000)
##D     B <- 100 
##D     cox.err <- rep(NA, B) 
##D     cox.f <- as.formula(Surv(days,status)~.)  
##D     pbc.data <- pbc[apply(is.na(pbc), 1, sum) == 0,] ##remove NA's 
##D     cat("Out-of-bag Cox Analysis ...", "\n")
##D     for (b in 1:B) {
##D         cat("Cox bootstrap", b, "\n") 
##D         bag.sample <- sample(1:dim(pbc.data)[1],
##D                              dim(pbc.data)[1],
##D                              replace = TRUE) 
##D         oob.sample <- setdiff(1:dim(pbc.data)[1], bag.sample)
##D         train <- pbc.data[bag.sample,]
##D         test <- pbc.data[oob.sample,]
##D         cox.out <- coxph(cox.f, train)
##D         cox.out <- tryCatch({coxph(cox.f, train)}, error=function(ex){NULL})
##D         if (is.list(cox.out)) {
##D           cox.predict <- predict(cox.out, test)
##D           cox.err[b] <- rcorr.cens(cox.predict, 
##D                  Surv(pbc.data$days[oob.sample], pbc.data$status[oob.sample]))[1]
##D         }
##D      }
##D      cat("Error rates:", "\n")
##D      cat("Random Survival Forests:", pbc3.out$err.rate[pbc3.out$ntree], "\n")
##D      cat("         Cox Regression:", mean(cox.err, na.rm = TRUE), "\n")
##D }
##D 
##D # Example 7:  Using an external data set.
##D 
##D file.in <- "other.data"
##D other.data <- read.table(file.in, header = TRUE)
##D rsf.f <- as.formula(Survrsf(time, status)~.)
##D rsf.out <- rsf(formula = rsf.f, data = other.data) 
##D 
## End(Not run)



